.. _costs:

Costs and savings
=================

Costs
-----

.. currentmodule:: skchange.costs

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    cost_factory
    init_mean_cost
    mean_cost

Savings
-------

.. autosummary::
    :toctree: auto_generated/
    :template: functions.rst

    saving_factory
    init_mean_saving
    mean_saving
